diff --git a/config-templates/config.php b/config-templates/config.php
index d2459694dd103a5aa1acd7ee8373071b2c2c22fe..de3dd82d13d26e04e78480d685205faeaf055a9f 100644
--- a/config-templates/config.php
+++ b/config-templates/config.php
@@ -471,7 +471,7 @@ $config = [
      ***********/
 
     /*
      * Configuration for enabling/disabling modules. By default the 'core' and 'saml' modules are enabled.
      *
      * Example:
      *
@@ -485,6 +485,7 @@ $config = [
      'module.enable' => [
          'exampleauth' => false,
          'core' => true,
+         'admin' => true,
          'saml' => true
      ],
@@ -471,7 +471,7 @@ $config = [
 
     /*
-     * Configuration for enabling/disabling modules. By default the 'core' and 'saml' modules are enabled.
+     * Configuration for enabling/disabling modules. By default the 'core', 'admin' and 'saml' modules are enabled.
      *
      * Example: